==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/AllowedFlexVolumeBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AllowedFlexVolumeBuilder extends io.fabric8.openshift.api.model.AllowedFlexVolumeFluentImpl<io.fabric8.openshift.api.model.AllowedFlexVolumeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.AllowedFlexVolume,io.fabric8.openshift.api.model.AllowedFlexVolumeBuilder>{
  public AllowedFlexVolumeBuilder() {
    this(false);
  }
  public AllowedFlexVolumeBuilder(java.lang.Boolean validationEnabled) {
    this(new AllowedFlexVolume(), validationEnabled);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent) {
    this(fluent, false);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AllowedFlexVolume(), validationEnabled);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent,io.fabric8.openshift.api.model.AllowedFlexVolume instance) {
    this(fluent, instance, false);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent,io.fabric8.openshift.api.model.AllowedFlexVolume instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDriver(instance.getDriver()); 
    this.validationEnabled = validationEnabled; 
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolume instance) {
    this(instance,false);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolume instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDriver(instance.getDriver()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.AllowedFlexVolume build() {
    AllowedFlexVolume buildable = new AllowedFlexVolume(fluent.getDriver());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AllowedFlexVolumeBuilder that = (AllowedFlexVolumeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/AllowedFlexVolumeBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AllowedFlexVolumeBuilder extends io.fabric8.openshift.api.model.AllowedFlexVolumeFluentImpl<io.fabric8.openshift.api.model.AllowedFlexVolumeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.AllowedFlexVolume,io.fabric8.openshift.api.model.AllowedFlexVolumeBuilder>{
  public AllowedFlexVolumeBuilder() {
    this(false);
  }
  public AllowedFlexVolumeBuilder(java.lang.Boolean validationEnabled) {
    this(new AllowedFlexVolume(), validationEnabled);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent) {
    this(fluent, false);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AllowedFlexVolume(), validationEnabled);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent,io.fabric8.openshift.api.model.AllowedFlexVolume instance) {
    this(fluent, instance, false);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent,io.fabric8.openshift.api.model.AllowedFlexVolume instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDriver(instance.getDriver()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolume instance) {
    this(instance,false);
  }
  public AllowedFlexVolumeBuilder(io.fabric8.openshift.api.model.AllowedFlexVolume instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDriver(instance.getDriver()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.AllowedFlexVolumeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.AllowedFlexVolume build() {
    AllowedFlexVolume buildable = new AllowedFlexVolume(fluent.getDriver());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AllowedFlexVolumeBuilder that = (AllowedFlexVolumeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
